bic.mlogit(f, data, choices = NULL, base.choice = 1,
varying = NULL, sep = ".", approx=TRUE,
include.intercepts = TRUE, verbose = FALSE, ...)mnl.spec.data is reduced to containchoices.data that are alternative-specific.TRUE, the function uses approximate likelihoods as they come out of the Begg & Gray approximation. If FALSE, the MNL maximum likelihood estimation is used in the last step of the model selection procedure. Note that tf contains the intercept, i.e. it does not contain bic.glm function of the bic.mlogit containing the following components:bic.glm which results from applying BMA on the binary logistic data.mlogit2logit function.mnl.spec containing the MNL specification of the full model.mnl.spec containing specifications for each selected model.approx argument.vignette('conversion').The function then applies the bic.glm function of the approx is FALSE, the maximum likelihood estimation (MLE) is applied to all selected models and the Bayesian Information Criterium (BIC) is recomputed using the log-likelihood of the full multinomial logistic regression model. Note that this step can be computationally very expensive. We suggest when using this option, set the verbose argument to TRUE to follow the computation progress. Note that one can use the estimate.mlogit function on the resulting object which performs the MLE on selected models only.
The include.intercepts=TRUE (default), asc for all the remaining alternatives are also always included in the selected models. If it is set to FALSE, the asc of the remaining alternatives (i.e. third and higher) are treated as ordinary variables, i.e candidates for selection as well as exclusion.
Yeung, K.Y., Bumgarner, R.E., Raftery, A.E. (2005) Bayesian model averaging: development of an improved multi-class, gene selection and classification tool for microarray data. Bioinformatics 21 (10), 2394--2402.
bic.glm, summary.bic.mlogit, imageplot.mlogit, estimate.mlogit.data('heating')
res <- bic.mlogit(depvar ~ ic + oc + income + rooms, heating, choices=1:5,
varying=3:12, verbose=TRUE, approx=FALSE, sep='')
summary(res)
imageplot.mlogit(res)
plot(res)
# use approximate BMA and estimate the models afterwards
res <- bic.mlogit(depvar ~ ic + oc | income + rooms, heating, choices=1:5,
varying=3:12, verbose=TRUE, approx=TRUE, sep='')
summary(res)
estimate.mlogit(res, heating)Run the code above in your browser using DataLab