bic.glm of the bic.mlogit which runs the Bayesian Model Averaging on multinomial logit data. Results can be explored using summary.bic.mlogit, imageplot.mlogit, or plot.bic.mlogit functions.An MNL estimation of a single model can be done using estimate.mlogit. Use summary.mnl to view its results.
Train, K.E. (2003) Discrete Choice Methods with Simulation. Cambridge University Press. Yeung, K.Y., Bumgarner, R.E., Raftery, A.E. (2005) Bayesian model averaging: development of an improved multi-class, gene selection and classification tool for microarray data. Bioinformatics 21 (10), 2394--2402.
bic.glm