Learn R Programming

mlogitBMA (version 0.1-6)

summary.mnl: Summary for Results of a Multinomial Logit Estimation

Description

Gives a summary for an object of class mnl which contains results of a multinomial logit estimation.

Usage

# S3 method for mnl
summary (object, …)

Arguments

object

Object of class mnl

Not used.